pub struct ActivationState {
xdg_activation: XdgActivationV1,
}Expand description
State for xdg-activation
Fields
xdg_activation: XdgActivationV1Implementations
Sourceimpl ActivationState
impl ActivationState
Sourcepub fn bind<State>(
globals: &GlobalList,
qh: &QueueHandle<State>,
) -> Result<ActivationState, BindError>
pub fn bind<State>( globals: &GlobalList, qh: &QueueHandle<State>, ) -> Result<ActivationState, BindError>
Bind the xdg-activation global
Sourcepub fn activate<D>(&self, surface: &WlSurface, token: String)
pub fn activate<D>(&self, surface: &WlSurface, token: String)
Activate a surface with the provided token.
Sourcepub fn request_token<D>(&self, qh: &QueueHandle<D>, request_data: RequestData)where
D: ActivationHandler<RequestData = RequestData> + Dispatch<XdgActivationTokenV1, RequestData> + 'static,
pub fn request_token<D>(&self, qh: &QueueHandle<D>, request_data: RequestData)where
D: ActivationHandler<RequestData = RequestData> + Dispatch<XdgActivationTokenV1, RequestData> + 'static,
Request a token for surface activation.
To attach custom data to the request implement RequestDataExt on a custom type
and use Self::request_token_with_data instead.
Sourcepub fn request_token_with_data<D, R>(
&self,
qh: &QueueHandle<D>,
request_data: R,
)where
D: ActivationHandler<RequestData = R> + Dispatch<XdgActivationTokenV1, R> + 'static,
R: RequestDataExt + 'static,
pub fn request_token_with_data<D, R>(
&self,
qh: &QueueHandle<D>,
request_data: R,
)where
D: ActivationHandler<RequestData = R> + Dispatch<XdgActivationTokenV1, R> + 'static,
R: RequestDataExt + 'static,
Request a token for surface activation with user data.
To use this method you need to provide [delegate_activation] with your custom type.
E.g. delegate_activation!(SimpleWindow, MyRequestData);